@@ -4,7 +4,7 @@
  *
  * client specific stuff
  *
- * $Id: client.c,v 1.14 2005/11/05 21:40:44 jon Exp $
+ * $Id: client.c 564 2006-07-24 00:52:28Z jon $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -25,6 +25,8 @@
 #include "msg.h"
 #include "record.h"
 #include "udp.h"
+#include "color.h"
+#include "ui.h"
 
 /* send an auth packet and wait for a response (if not CHPWD).
    returns the error code from the ack, or error from write/read */
@@ -290,6 +292,8 @@ int procPlanet(Unsgn8 *buf)
   splan->name[MAXPLANETNAME - 1] = 0;
   strncpy(Planets[pnum].name, splan->name, MAXPLANETNAME);
 
+  uiUpdatePlanet(pnum);
+
   return TRUE;
 }
 
@@ -318,6 +322,10 @@ int procPlanetSml(Unsgn8 *buf)
 
   Planets[pnum].uninhabtime = (int)splansml->uninhabtime;
 
+#if 0
+  clog("%s: %d scanned = %x", __FUNCTION__, pnum, splansml->scanned);
+#endif
+
   return TRUE;
 }
 
@@ -510,6 +518,8 @@ int procTorpEvent(Unsgn8 *buf)
   Ships[snum].torps[tnum].dy = 
     (real)((real)((Sgn32)ntohl(storpev->dy)) / 1000.0);
 
+  uiUpdateTorpDir(snum, tnum);
+
   return TRUE;
 }
 
@@ -1030,15 +1040,26 @@ void processPacket(Unsgn8 *buf)
  * game.  This routine will send a CPCMD_KEEPALIVE packet every 60 seconds
  * if a UDP connection is enabled.  Seems to solve clute's problem.
  */
-void sendUDPKeepAlive(void)
+void sendUDPKeepAlive(Unsgn32 timebase)
 {
   static Unsgn32 katime = 0;     /* UDP keepalive packets */
-  const Unsgn32 kawait = 60000;  /* ms (60 seconds) */
-  Unsgn32 iternow = clbGetMillis();  
+  static const Unsgn32 kawait = 30000;  /* ms (30 seconds) */
+  Unsgn32 iternow;
+
+  if (!cInfo.doUDP)
+    return;                     /* no point */
+
+  if (timebase)                 /* don't query the clock */
+    iternow = timebase;
+  else
+    iternow = clbGetMillis();  
 
   /* send a UDP keepalive packet if it's time */
   if (((iternow - katime) > kawait) && cInfo.usock != -1)
     {
+#if 0
+      clog("%s: Sending CPCMD_KEEPALIVE\n", __FUNCTION__);
+#endif
       sendCommand(CPCMD_KEEPALIVE, 0);
       katime = iternow;
     }
