@@ -4,7 +4,7 @@
  *
  * conf.c - handle configuration issues, both personal and system wide.
  *
- * $Id: conf.c,v 1.20 2005/11/05 21:40:44 jon Exp $
+ * $Id: conf.c 636 2006-09-02 00:23:06Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -43,6 +43,11 @@ void confSetTelnetClientMode(int telnetc)
   return;
 }
 
+int confGetTelnetClientMode(void)
+{
+  return telnetClient;
+}
+
 /* set default sys config */
 static void setSysConfDefaults(void)
 {
@@ -68,7 +73,7 @@ static void setSysConfDefaults(void)
 /* set default user config */
 void setUserConfDefaults(void)
 {
-  int i;
+  int i, j;
 
   UserConf.DoAlarms = TRUE;
   UserConf.ShowPhasers = TRUE;
@@ -80,7 +85,12 @@ void setUserConfDefaults(void)
   UserConf.MessageBell = TRUE;
   UserConf.NoColor = FALSE;
   UserConf.NoRobotMsgs = FALSE;
-  UserConf.UpdatesPerSecond = 5;	/* default of 5 per sec */
+
+  if (telnetClient)             /* 5/sec for telneters, 10 for everyone else */
+    UserConf.UpdatesPerSecond = 5;
+  else
+    UserConf.UpdatesPerSecond = 10;
+
   UserConf.DistressToFriendly = FALSE;
   UserConf.AltHUD = FALSE;
   UserConf.DoLRTorpScan = TRUE;
@@ -88,15 +98,93 @@ void setUserConfDefaults(void)
   UserConf.DoETAStats = TRUE;
   UserConf.EnemyShipBox = TRUE;
   UserConf.doVBG = TRUE;
-  
+
+  UserConf.DoShields = TRUE;
+  UserConf.DoTacBkg = FALSE;
+  UserConf.DoTacShade = 50;
+
   for (i=0; i<MAX_MACROS; i++)
+    UserConf.MacrosF[i][0] = EOS;
+
+  for (i=0; i<CONF_MAXBUTTONS; i++)
     {
-      UserConf.MacrosF[i][0] = EOS;
+      for (j=0; j<CONF_MAXMODIFIERS; j++)
+        UserConf.Mouse[i][j][0] = EOS;
+
+      /* set up default mouse macros, '\a' mean 'angle' substitution */
+
+      /* fire phaser (left button (0), no modifiers) */
+      strncpy(UserConf.Mouse[0][0], 
+              "f\\a\r", MAX_MACRO_LEN);
+
+      /* set course (middle button (1), no modifiers) */
+      strncpy(UserConf.Mouse[1][0], 
+              "k\\a\r", MAX_MACRO_LEN);
+
+      /* fire torp (right button (2), no modifiers) */
+      strncpy(UserConf.Mouse[2][0], 
+              "p\\a\r", MAX_MACRO_LEN);
     }
 
   return;
 }
 
+/* here we look for a ~/.conquest/ directory, and try to create it if it
+   does nt exist */
+static void checkCreateUserConfDir(void)
+{
+  char buffer[BUFFER_SIZE];
+  struct stat sbuf;
+  char *home;
+  
+  if (telnetClient)             /* ...except for telnet users */
+    return;
+  
+  if ((home = getenv("HOME")) == NULL)
+    {
+      clog("checkCreateUserConfDir(): getenv(HOME) failed");
+      
+      return;
+    }
+  
+  /* start building the filename */
+  snprintf(buffer, sizeof(buffer) - 1, "%s/.conquest", home);
+  
+  if (stat(buffer, &sbuf) >= 0)
+    {
+      /* make sure it's a directory */
+      
+#ifdef S_ISDIR
+      if (!S_ISDIR(sbuf.st_mode))
+        {
+          clog("checkCreateUserConfDir(): %s exists, but is not a directory.",
+               buffer);
+          return;
+        }
+#endif
+      
+      /* else everythings ok (if S_ISDIR was understood) */
+      return;
+    }
+  
+  /* try to create it */
+  if (mkdir(buffer, (S_IRUSR | S_IWUSR | S_IXUSR |S_IRGRP | S_IXGRP)) < 0)
+    {                             /* not happy */
+      clog("checkCreateUserConfDir(): mkdir(%s) failed: %s.",
+           buffer, strerror(errno));
+      return;
+    }
+  else
+    {
+      clog("Created '%s' config directory.",
+           buffer);
+    }      
+  
+  /* we're done */
+  
+  return;
+}
+
 /* GetSysConf(int checkonly) - load system-wide configuration values */
 /*  If checkonly is TRUE, then just load internel defaults, and the existing
     conquesrtc file, if there.  Don't output errmsgs since this will
@@ -217,7 +305,16 @@ int GetSysConf(int checkonly)
 		      case CTYPE_NUMERIC:
 			if (alldig(bufptr))
 			  {
-			    *((int *) SysConfData[j].ConfValue) = atoi(bufptr);
+                            int *n = ((int *) SysConfData[j].ConfValue);
+
+			    *n = atoi(bufptr);
+
+                            if (*n < SysConfData[j].min)
+                              *n = SysConfData[j].min;
+
+                            if (*n > SysConfData[j].max)
+                              *n = SysConfData[j].max;
+
 			    SysConfData[j].Found = TRUE;
 			    FoundOne = TRUE;
 			  }
@@ -301,6 +398,58 @@ int GetSysConf(int checkonly)
   return(TRUE);
 }
 
+/* parse a mouse macro mod/but string */
+static int 
+parseMouseModNum(char *str, Unsgn32 *mods, Unsgn32 *button)
+{
+  int done = FALSE;
+  if (!mods || !button || !str)
+    return FALSE;
+
+  if (!*str)
+    return FALSE;
+
+  *mods = 0;
+  *button = 0;
+
+  while (*str && !done)
+    {
+      if (!isdigit(*str))
+        {
+          /* check for 'a', 'c', and 's' */
+          switch (*str)
+            {
+            case 'a':
+              *mods |= (CQ_KEY_MOD_ALT >> CQ_MODIFIER_SHIFT) ;
+              break;
+            case 'c':
+              *mods |= (CQ_KEY_MOD_CTRL >> CQ_MODIFIER_SHIFT);
+              break;
+            case 's':
+              *mods |= (CQ_KEY_MOD_SHIFT >> CQ_MODIFIER_SHIFT);
+              break;
+            default:
+              clog("parseMouseModNum: Invalid modifier char '%c'",
+                   *str);
+              return FALSE;
+              break;
+            }
+          str++;
+        }
+      else                      /* the mouse button number, always last */
+        {
+          *button = atoi(str);
+          done = TRUE;
+        }   
+    }
+
+  if (*button < 0 || *button >= CONF_MAXBUTTONS)
+    return FALSE;
+  if (*mods < 0 || *mods >= CONF_MAXMODIFIERS)
+    return FALSE;
+
+  return TRUE;
+}
 				/* get user's configuration */
 int GetConf(int usernum)
 {
@@ -308,7 +457,6 @@ int GetConf(int usernum)
   int i, j, n;
   char conf_name[MID_BUFFER_SIZE];
   char *homevar, *cptr;
-  char home[HOME_BUFSZ];
   char buffer[BUFFER_SIZE];
   int buflen;
   char *bufptr;
@@ -317,6 +465,9 @@ int GetConf(int usernum)
   /* init some defaults */
   setUserConfDefaults();
 
+  /* check for the user config dir */
+  checkCreateUserConfDir();
+
   /* a telnet client leaves here after the defaults are set */
   if (telnetClient)
     return TRUE;
@@ -330,10 +481,8 @@ int GetConf(int usernum)
       return(ERR);
     }
 
-  memset(home, 0, HOME_BUFSZ);
-  strncpy(home, homevar, HOME_BUFSZ - 1);
-
-  snprintf(conf_name, sizeof(conf_name)-1, "%s/%s", home, CONFIG_FILE);
+  snprintf(conf_name, sizeof(conf_name)-1, "%s/.conquest/%s", 
+           homevar, CONFIG_FILE);
 
   if ((conf_fd = fopen(conf_name, "r")) == NULL)
     {
@@ -445,7 +594,7 @@ int GetConf(int usernum)
 #endif
 				/* clean it first... */
 				memset((char *)(((char *)ConfData[j].ConfValue)
-					 + ((n - 1) * MAX_MACRO_LEN)), 
+                                                + ((n - 1) * MAX_MACRO_LEN)), 
 				       0,
 				       MAX_MACRO_LEN);
 				strncpy((char *)(((char *)ConfData[j].ConfValue)
@@ -459,10 +608,52 @@ int GetConf(int usernum)
 				
 			break;
 
+		      case CTYPE_MOUSE:
+                        {
+                          Unsgn32 mods;
+                          Unsgn32 button;
+
+                          /* need to parse out mods/button #. */
+                          cptr = strchr(bufptr, '=');
+
+                          if (cptr != NULL)
+                            {	/* valid entry */
+                              *cptr = '\0';
+                              if (parseMouseModNum(bufptr,
+                                                   &mods, &button))
+                                { /* got a valid button and modifier(s) */
+                                  
+#if defined(DEBUG_CONFIG)
+                                  clog("GetConf(): Mouse %d %d, value '%s' read",
+                                       button, mods, (char *)cptr + 1);
+#endif
+                                  /* clean it first... */
+                                  memset(UserConf.Mouse[button][mods], 
+                                         0,
+                                         MAX_MACRO_LEN);
+                                  strncpy(UserConf.Mouse[button][mods], 
+                                          Str2Macro((char *)cptr + 1), 
+                                          MAX_MACRO_LEN - 1);
+                                  ConfData[j].Found = TRUE;
+                                  FoundOne = TRUE;
+                                }
+                            }
+                        }
+			break;
+
 		      case CTYPE_NUMERIC:
 			if (alldig(bufptr))
 			  {
-			    *((int *) ConfData[j].ConfValue) = atoi(bufptr);
+                            int *n = ((int *) ConfData[j].ConfValue);
+
+			    *n = atoi(bufptr);
+
+                            if (*n < ConfData[j].min)
+                              *n = ConfData[j].min;
+
+                            if (*n > ConfData[j].max)
+                              *n = ConfData[j].max;
+
 			    ConfData[j].Found = TRUE;
 			    FoundOne = TRUE;
 			  }
@@ -493,7 +684,7 @@ int GetConf(int usernum)
 
 				/* see if we found the version */
   if (ConfData[CF_VERSION].Found == FALSE)
-    {				/* .conquestrc version not found */
+    {				/* conquestrc version not found */
 #ifdef DEBUG_CONFIG
       clog("GetConf(): Incorrect version found. - rebuilding");
 #endif
@@ -504,7 +695,8 @@ int GetConf(int usernum)
       for (i=0; i<CfEnd; i++)
 	{
 	  if (ConfData[i].ConfType != CTYPE_NULL && 
-	      ConfData[i].ConfType != CTYPE_MACRO )
+	      ConfData[i].ConfType != CTYPE_MACRO && 
+              ConfData[i].ConfType != CTYPE_MOUSE )
 	    if (ConfData[i].Found != TRUE)
 	      {
 #ifdef DEBUG_CONFIG
@@ -524,7 +716,6 @@ int SaveUserConfig(void)
 {
   char conf_name[MID_BUFFER_SIZE];
   char *homevar;
-  char home[HOME_BUFSZ];
 
 				/* start building the filename */
   if ((homevar = getenv("HOME")) == NULL)
@@ -535,10 +726,8 @@ int SaveUserConfig(void)
       return(ERR);
     }
 
-  memset(home, 0, HOME_BUFSZ);
-  strncpy(home, homevar, HOME_BUFSZ - 1);
-
-  snprintf(conf_name, sizeof(conf_name)-1, "%s/%s", home, CONFIG_FILE);
+  snprintf(conf_name, sizeof(conf_name)-1, "%s/.conquest/%s", 
+           homevar, CONFIG_FILE);
 
 #ifdef DEBUG_OPTIONS
   clog("SaveUserConfig(): saving user config: conf_name = '%s'", conf_name);
@@ -591,8 +780,12 @@ char *Str2Macro(char *str)
 		  s++;
 		  break;
 		case '\\':
+		  retstr[i++] = '\\';
+                  s++;
+                  break;
 		default:
 		  retstr[i++] = '\\';
+		  retstr[i++] = *s;
                   s++;
                   break;
 		}
@@ -648,11 +841,13 @@ char *Macro2Str(char *str)
 	  retstr[i++] = 'n';
 	  s++;
 	  break;
+#if 0
 	case '\\':
 	  retstr[i++] = '\\';
 	  retstr[i++] = '\\';
 	  s++;
 	  break;
+#endif
 	default:
 	  retstr[i++] = *s;
 	  s++;
@@ -744,6 +939,38 @@ int MakeConf(char *filename)
       if (ConfData[j].ConfType != CTYPE_NULL)
 	switch (ConfData[j].ConfType)
 	  {
+	  case CTYPE_MOUSE:
+            {
+              int b, m;
+
+              for (b=0; b < CONF_MAXBUTTONS; b++)
+                {
+                  for (m=0; m<CONF_MAXMODIFIERS; m++)
+                    {
+                      if (strlen(UserConf.Mouse[b][m]) != 0)
+                        {
+                          char buffer[16]; /* max 'acs\0' */
+                          
+                          buffer[0] = 0;
+                          if (m & (CQ_KEY_MOD_SHIFT >> CQ_MODIFIER_SHIFT))
+                            strcat(buffer, "s");
+                          if (m & (CQ_KEY_MOD_CTRL  >> CQ_MODIFIER_SHIFT))
+                            strcat(buffer, "c");
+                          if (m & (CQ_KEY_MOD_ALT   >> CQ_MODIFIER_SHIFT))
+                            strcat(buffer, "a");
+
+                          fprintf(conf_fd, "%s%s%d=%s\n",
+                                  ConfData[j].ConfName,
+                                  buffer,
+                                  b,
+                                  Macro2Str(UserConf.Mouse[b][m]));
+                        }
+
+                    }
+                }
+            }
+	    break;
+
 	  case CTYPE_MACRO:
 	    for (n=0; n < MAX_MACROS; n++)
 	      {
