@@ -1,7 +1,7 @@
 
 /************************************************************************
  *
- * $Id: conqdef.h,v 1.17 2004/12/26 08:19:31 jon Exp $
+ * $Id: conqdef.h 568 2006-08-05 20:10:21Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -49,6 +49,7 @@
 /*                  .Operate(), watch(): Get msg timestamp after action switch. */
 /*                  .Putship(): Increase smear factor slightly. */
 /*                  .*(): Converted maxwarp(), engeff() and weaeff() to macros. */
+/* 8.12  7Oct05     .clbInitPlanets(): mod for .planetsrc data input */
 
 /* Common block time stamp. */
 /* This define should be changed every time the common block changes. */
@@ -59,7 +60,8 @@
 /*#define COMMONSTAMP 980628 		 stardate? */
 /*#define COMMONSTAMP 990124 		 stardate? */
 /*#define COMMONSTAMP 20001231 		 stardate? */
-#define COMMONSTAMP 20030829 		 /* stardate? */
+#define COMMONSTAMP 20030829
+
 
 /* Copyright notice string. */
 #define COPYRIGHT "(C) 1983-1986 by Jef Poskanzer and Craig Leres"
@@ -68,6 +70,9 @@
 # define PI 3.141592654
 #endif
 
+#define CONQ_HTTP   "http://radscan.com/conquest.html"
+#define CONQ_MLIST  "Mailing list: majordomo@radscan.com, send 'subscribe conquest' in body"
+
 #define MAXSHIPS 20 		/* number of available ships */
 
   /* Values for sstatus() */
@@ -589,6 +594,9 @@
 #define UT_LOCAL (0)
 #define UT_REMOTE (1)
 
+#define TEXFILEMAX 64           /* maximum lenth of a texture filename (no
+                                   path) */
+
 /* Macros, here order is important. */
 
 #define my_rint(x) ((real)floor((x) + 0.5)) /* standard round. */
@@ -621,5 +629,8 @@
 #define bitSet(x, b)   ((x) |= (b))
 #define bitClear(x, b) ((x) &= ~(b))
 
+/* clamp */
+#undef CLAMP
+#define CLAMP(_min, _max, _val) (((_val) < (_min)) ? (_min) : (((_val) > (_max)) ? (_max) : (_val)))
 
 #endif /*  CONQDEF_H_INCLUDED */
