@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: conquest.c,v 1.42 2005/12/28 06:13:28 jon Exp $
+ * $Id: conquest.c 636 2006-09-02 00:23:06Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -49,6 +49,7 @@
 #include "cuclient.h"
 #include "udp.h"
 #include "meta.h"
+#include "conqinit.h"
 
 #define CLIENTNAME "Conquest"	/* our client name */
 
@@ -115,7 +116,7 @@ void dead( int snum, int leave );
 void printUsage()
 {
   printf("Usage: conquest [-m ][-s server[:port]] [-r recfile] [ -t ]\n");
-  printf("                [ -M <metaserver> ] [ -u ]\n\n");
+  printf("                [ -M <metaserver> ] [ -u ] [ -B ]\n\n");
   printf("    -m               query the metaserver\n");
   printf("    -s server[:port] connect to <server> at <port>\n");
   printf("                      default: localhost:1701\n");
@@ -127,8 +128,8 @@ void printUsage()
   printf("    -M metaserver   specify alternate <metaserver> to contact.\n");
   printf("                     default: %s\n", META_DFLT_SERVER);
   printf("    -P <cqr file>   Play back a Conquest recording (.cqr)\n");
-  printf("    -d <dly>        specify default framedelay for CQR playback.\n");
-  printf("                    (example -d .01, for 1/100sec frame delay\n");
+  printf("    -B              Benchmark mode.  When playing back a recording,\n");
+  printf("                    the default playback speed will be as fast as possible.\n");
   printf("    -u              do not attempt to use UDP from server.\n");
   return;
 }
@@ -263,16 +264,19 @@ int main(int argc, char *argv[])
   cInfo.isLoggedIn = FALSE;
   cInfo.remoteport = CN_DFLT_PORT;
 
-  setSystemLog(FALSE);	/* use $HOME for logfile */
+  setSystemLog(FALSE, FALSE);	/* use $HOME for logfile */
   if (!getLocalhost(cInfo.localhost, MAXHOSTNAME))
     return(1);
 
   cInfo.remotehost = strdup("localhost"); /* default to your own server */
 
   /* check options */
-  while ((i = getopt(argc, argv, "mM:s:r:tP:d:u")) != EOF)    /* get command args */
+  while ((i = getopt(argc, argv, "mM:s:r:tP:Bu")) != EOF)    /* get command args */
     switch (i)
       {
+      case 'B':                 /* Benchmark mode, set frameDelay to 0.0 */
+        frameDelay = 0.0;
+        break;
       case 'm':
         wantMetaList = TRUE;
         break;
@@ -331,10 +335,6 @@ int main(int argc, char *argv[])
         Context.recmode = RECMODE_PLAYING;
         break;
 
-      case 'd':                 /* framedelay */
-        framedelay = ctor(optarg);
-        break;
-
       case 'u':
         cInfo.tryUDP = FALSE;
         break;
@@ -346,6 +346,9 @@ int main(int argc, char *argv[])
 
   rndini( 0, 0 );		/* initialize random numbers */
   
+  cqiLoadRC(CQI_FILE_CONQINITRC, NULL, 1, 0);
+
+
 #ifdef DEBUG_CONFIG
   clog("%s@%d: main() Reading Configuration files.", __FILE__, __LINE__);
 #endif
@@ -916,11 +919,17 @@ void conqds( int multiple, int switchteams )
     cprintf( lin,0,ALIGN_CENTER,"#%d#%s (%s)",YellowLevelColor,
 	   ConquestVersion, ConquestDate);
   
+  lin++;
+  lin++;
+  cprintf(lin,0,ALIGN_CENTER,"#%d#%s", MagentaColor, CONQ_HTTP);
+  lin++;
+  cprintf(lin,0,ALIGN_CENTER,"#%d#%s", MagentaColor, CONQ_MLIST);
+  lin++;
   lin++;
   cprintf(lin,0,ALIGN_CENTER,"#%d#%s",NoColor, "Options:");
   
   col = 13;
-  lin+=2;
+  lin++;
   i = lin;
   cprintf(lin,col,ALIGN_NONE,sfmt, 'e', "enter the game");
   if ( Context.hasnewsfile )
@@ -1652,32 +1661,10 @@ void doburst( int snum )
   
   cdclrl( MSG_LIN2, 1 );
   
-  if ( SCLOAKED(snum) )
-    {
-      mcuPutMsg( "The cloaking device is using all available power.",
-	       MSG_LIN1 );
-      return;
-    }
-  if ( Ships[snum].wfuse > 0 )
-    {
-      mcuPutMsg( "Weapons are currently overloaded.", MSG_LIN1 );
-      return;
-    }
-  if ( Ships[snum].fuel < TORPEDO_FUEL )
-    {
-      mcuPutMsg( "Not enough fuel to launch a torpedo.", MSG_LIN1 );
-      return;
-    }
-  
   if ( mcuGetTarget( "Torpedo burst: ", MSG_LIN1, 1, &dir, Ships[snum].lastblast ) )
     {
-      if ( ! clbCheckLaunch( snum, 3 ) )
-	mcuPutMsg( ">TUBES EMPTY<", MSG_LIN2 );
-      else
-	{			/* a local approx */
-	  sendFireTorps(3, dir);
-	  cdclrl( MSG_LIN1, 1 );
-	}
+      sendFireTorps(3, dir);
+      cdclrl( MSG_LIN1, 1 );
     }
   else
     {
@@ -1697,7 +1684,6 @@ void doburst( int snum )
 void docloak( int snum )
 {
   string pmt="Press TAB to engage cloaking device: ";
-  string nofuel="Not enough fuel to engage cloaking device.";
   
   cdclrl( MSG_LIN1, 1 );
   cdclrl( MSG_LIN2, 1 );
@@ -1705,18 +1691,6 @@ void docloak( int snum )
   if ( SCLOAKED(snum) )
     {
       sendCommand(CPCMD_CLOAK, 0);
-      mcuPutMsg( "Cloaking device disengaged.", MSG_LIN1 );
-      SFCLR(snum, SHIP_F_CLOAKED); /* do it locally */
-      return;
-    }
-  if ( Ships[snum].efuse > 0 )
-    {
-      mcuPutMsg( "Engines are currently overloaded.", MSG_LIN1 );
-      return;
-    }
-  if ( Ships[snum].fuel < CLOAK_ON_FUEL )
-    {
-      mcuPutMsg( nofuel, MSG_LIN1 );
       return;
     }
   
@@ -1725,15 +1699,7 @@ void docloak( int snum )
   if ( cdgetx( pmt, MSG_LIN1, 1, TERMS, cbuf, MSGMAXLINE,
 	       TRUE) == TERM_EXTRA )
     {
-      if ( ! clbUseFuel( snum, CLOAK_ON_FUEL, FALSE, TRUE ) )
-	{			/* an approximation of course... */
-	  mcuPutMsg( nofuel, MSG_LIN2 );
-	  return;
-	}
-
       sendCommand(CPCMD_CLOAK, 0);
-      SFSET(snum, SHIP_F_CLOAKED); /* do it locally */
-      mcuPutMsg( "Cloaking device engaged.", MSG_LIN2 );
     }
   cdclrl( MSG_LIN1, 1 );
   
@@ -2202,7 +2168,7 @@ void dohelp( void )
   tlin++;
   cprintf(tlin,col,ALIGN_NONE,sfmt, "o", "come into orbit");
   tlin++;
-  cprintf(tlin,col,ALIGN_NONE,sfmt, "p", "launch photon torpedoes");
+  cprintf(tlin,col,ALIGN_NONE,sfmt, "p", "launch photon torpedo");
   tlin++;
   cprintf(tlin,col,ALIGN_NONE,sfmt, "P", "launch photon torpedo burst");
   tlin++;
@@ -2352,23 +2318,6 @@ void dolastphase( int snum )
 {
   cdclrl( MSG_LIN1, 1 );
   
-  if ( SCLOAKED(snum) )
-    {
-      mcuPutMsg( "The cloaking device is using all available power.",
-	       MSG_LIN2 );
-      return;
-    }
-  if ( Ships[snum].wfuse > 0 )
-    {
-      mcuPutMsg( "Weapons are currently overloaded.", MSG_LIN1 );
-      return;
-    }
-  if ( Ships[snum].fuel < PHASER_FUEL )
-    {
-      mcuPutMsg( "Not enough fuel to fire phasers.", MSG_LIN2 );
-      return;
-    }
-  
   sendCommand(CPCMD_FIREPHASER, (Unsgn16)(Ships[snum].lastphase * 100.0));
   cdclrl( MSG_LIN2, 1 );
   
@@ -2439,33 +2388,11 @@ void dophase( int snum )
   real dir;
   
   cdclrl( MSG_LIN2, 1 );
-  if ( SCLOAKED(snum) )
-    {
-      mcuPutMsg( "The cloaking device is using all available power.",
-	       MSG_LIN1 );
-      return;
-    }
-  if ( Ships[snum].wfuse > 0 )
-    {
-      mcuPutMsg( "Weapons are currently overloaded.", MSG_LIN1 );
-      return;
-    }
-  if ( Ships[snum].fuel < PHASER_FUEL )
-    {
-      mcuPutMsg( "Not enough fuel to fire phasers.", MSG_LIN1 );
-      return;
-    }
-  
+
   if ( mcuGetTarget( "Fire phasers: ", MSG_LIN1, 1, &dir, Ships[snum].lastblast ) )
     {
-      if ( Ships[snum].pfuse <= 0 && clbUseFuel( snum, PHASER_FUEL, 
-					      TRUE, FALSE ) )
-	{			/* a local approximation of course */
-	  mcuPutMsg( "Firing phasers...", MSG_LIN2 );
-	  sendCommand(CPCMD_FIREPHASER, (Unsgn16)(dir * 100.0));
-	}
-      else
-	mcuPutMsg( ">PHASERS DRAINED<", MSG_LIN2 );
+      mcuPutMsg( "Firing phasers...", MSG_LIN2 );
+      sendCommand(CPCMD_FIREPHASER, (Unsgn16)(dir * 100.0));
     }
   else
     {
@@ -3280,18 +3207,18 @@ int play()
   /* start recording if neccessary */
   if (Context.recmode == RECMODE_STARTING)
     {
-      if (recordInitOutput(Context.unum, getnow(NULL, 0), Context.snum))
+      if (recordInitOutput(Context.unum, getnow(NULL, 0), Context.snum, 
+                           FALSE))
         {
           Context.recmode = RECMODE_ON;
         }
       else
         Context.recmode = RECMODE_OFF;
     }
-
-  /* need to tell the server to resend all the crap it already
-     sent in menu - our ship may have changed */
-  sendCommand(CPCMD_RELOAD, 0);
   
+  /* need to tell the server to resend all the data it already
+     sent in menu, since our ship might have changed. */
+  sendCommand(CPCMD_RELOAD, 0);
 
   /* While we're alive, field commands and process them. Inbound
      packets are handled by astservice() */
@@ -3363,7 +3290,7 @@ int play()
         }
 
       /* send a UDP keepalive packet if it's time */
-      sendUDPKeepAlive();
+      sendUDPKeepAlive(0);
 
     } /* while stillalive */
 	  
@@ -3400,6 +3327,7 @@ int welcome( int *unum )
   int pkttype;
   Unsgn8 buf[PKT_MAXSIZE];
   int sockl[2] = {cInfo.sock, cInfo.usock};
+  int done = FALSE;
   
   col=0;
 
@@ -3409,31 +3337,37 @@ int welcome( int *unum )
       return FALSE;
     }
 
-  /* now look for SP_CLIENTSTAT or SP_ACK */
-  if ((pkttype = 
-       readPacket(PKT_FROMSERVER, sockl, buf, PKT_MAXSIZE, 60)) <= 0)
+  while (!done)
     {
-      clog("welcome: read SP_CLIENTSTAT or SP_ACK failed: %d\n", pkttype);
-      return FALSE;
-    }
+      /* now look for SP_CLIENTSTAT or SP_ACK */
+      if ((pkttype = 
+           readPacket(PKT_FROMSERVER, sockl, buf, PKT_MAXSIZE, 60)) <= 0)
+        {
+          clog("welcome: read SP_CLIENTSTAT or SP_ACK failed: %d\n", pkttype);
+          return FALSE;
+        }
+      
+      switch (pkttype)
+        {
+        case SP_CLIENTSTAT:
+          scstat = *(spClientStat_t *)buf;
+          
+          *unum = (int)ntohs(scstat.unum);
+          Context.snum = scstat.snum;
+          Ships[Context.snum].team = scstat.team;
+          done = TRUE;
 
-  switch (pkttype)
-    {
-    case SP_CLIENTSTAT:
-      scstat = *(spClientStat_t *)buf;
-
-      *unum = (int)ntohs(scstat.unum);
-      Context.snum = scstat.snum;
-      Ships[Context.snum].team = scstat.team;
-
-      break;
-    case SP_ACK:
-      sack = (spAck_t *)buf;
-      break;
-    default:
-      clog("conquest:welcome: got unexpected packet type %d\n", pkttype);
-      return FALSE;
-      break;
+          break;
+        case SP_ACK:
+          sack = (spAck_t *)buf;
+          done = TRUE;
+          break;
+        default:
+          clog("welcome: got unexpected packet type %d. Ignoring.", 
+               pkttype);
+          done = FALSE;         /* redundant, but it gets the point across */
+          break;
+        }
     }
 
   if ( pkttype == SP_CLIENTSTAT && (scstat.flags & SPCLNTSTAT_FLAG_NEW) )
