@@ -4,7 +4,7 @@
  *
  * conquestd - the Conquest server/client driver
  *
- * $Id: conquestd.c,v 1.27 2005/12/25 20:24:00 jon Exp $
+ * $Id: conquestd.c 634 2006-09-01 23:34:12Z jon $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -36,6 +36,8 @@
 #include "servercmd.h"
 #include "meta.h"
 
+#include "conqinit.h"
+
 #define LISTEN_BACKLOG 5 /* # of requests we're willing to to queue */
 
 static Unsgn16 listenPort = CN_DFLT_PORT;
@@ -142,7 +144,7 @@ void checkMaster(void)
 
   if ((hp = gethostbyname(sInfo.localhost)) == NULL) 
     {
-      perror("gethostbyname");
+      clog("NET: gethostbyname() failed: %s", strerror(errno));
       exit (1);
     }
   
@@ -158,7 +160,7 @@ void checkMaster(void)
   /* allocate an open socket for incoming connections */
   if (( s = socket(hp->h_addrtype, SOCK_STREAM, 0)) < 0) 
     {
-      perror ( "socket" );
+      clog("NET: socket() failed: %s", strerror(errno));
       exit(1);
     }
   
@@ -167,7 +169,7 @@ void checkMaster(void)
    */
   if ( bind( s, (struct sockaddr *)&sa, sizeof ( sa )) < 0 ) 
     {
-      perror( "bind" );
+      clog("NET: bind() failed: %s", strerror(errno));
       exit(1);
     }
   
@@ -355,7 +357,7 @@ int main(int argc, char *argv[])
 #ifdef DEBUG_FLOW
   clog("%s@%d: main() mapping common block.", __FILE__, __LINE__);
 #endif
-  
+
   map_common();
 
   if ( *CBlockRevision != COMMONSTAMP )
@@ -398,21 +400,21 @@ int main(int argc, char *argv[])
 #else
 # if defined(HAVE_SETPGRP)
 #  if defined(SETPGRP_VOID)
-          setpgrp ();
+          setpgrp();
 #  else
-          setpgrp (0, getpid());
+          setpgrp(0, getpid());
 #  endif
 # endif
 
-          close (0);
-          close (1);
-          close (2);
+          close(0);
+          close(1);
+          close(2);
 
           /* Set up the standard file descriptors. */
 
-          (void) open ("/", O_RDONLY);        /* root inode already in core */
-          (void) dup2 (0, 1);
-          (void) dup2 (0, 2);
+          (void) open("/", O_RDONLY);        /* root inode already in core */
+          (void) dup2(0, 1);
+          (void) dup2(0, 2);
 
 #endif /* !HAVE_DAEMON */
 
@@ -444,10 +446,12 @@ int main(int argc, char *argv[])
 #endif
     }
 
-
-
   conqinit();			/* machine dependent initialization */
   
+  /* load the globals/planets/textures, for each client */
+  cqiLoadRC(CQI_FILE_CONQINITRC, NULL, 1, 0);
+  cqiLoadRC(CQI_FILE_TEXTURESRC, NULL, 1, 0);
+
   rndini( 0, 0 );		/* initialize random numbers */
   
   clog("CONNECT: client %s\n", sInfo.remotehost);
@@ -484,21 +488,24 @@ int main(int argc, char *argv[])
 /* responsible for updating the client */
 void updateProc(void)
 {
-#if 0
-  static Unsgn32 lastms = 0;
-  Unsgn32 millis = clbGetMillis();
-
-  if ((millis - lastms) > 100)
-    clog("millisdiff = %u", (millis - lastms));
-  lastms = millis;
-#endif
-
   /* Don't do anything if we're not supposed to. */
   if (sInfo.state != SVR_STATE_PLAY)
     return;
 
   stopUpdate();
 
+#if 0
+  {
+    /* debugging code to see update latencies */
+    static Unsgn32 lastms = 0;
+    Unsgn32 millis = clbGetMillis();
+    
+    if ((millis - lastms) > (int)((1.0 / (real)Context.updsec) * 1000.0))
+      clog("millisdiff = %u(%d)", (millis - lastms), Context.updsec);
+    lastms = millis;
+  }
+#endif
+
   /* update client view of the universe */
   updateClient(FALSE);
 
@@ -1093,8 +1100,8 @@ void handleSimpleCmdPkt(cpCommand_t *ccmd)
       break;
 
     case CPCMD_RELOAD:
-      procReload(ccmd);
       clbBlockAlarm();
+      procReload(ccmd);
       updateClient(TRUE);
       clbUnblockAlarm();
 
@@ -1251,7 +1258,10 @@ void menu(void)
 	  return;
 	}
       
-      if ( pkttype == 0 )	/* timeout */
+      /* we get sleepy if we are recieving no packets, of only
+         keepalive packets */
+      if ( pkttype == 0 || ((pkttype == CP_COMMAND) && 
+                            CPCMD_KEEPALIVE == (((cpCommand_t *)buf)->cmd)))
 	{
 	  /* We get here if a packet hasn't been recieved. */
 	  sleepy++;
@@ -1260,6 +1270,7 @@ void menu(void)
 	  continue; /* next */
 	}
 
+
       switch(pkttype)
 	{
 	case CP_SETNAME:
@@ -1555,7 +1566,15 @@ int play(void)
 	  Ships[Context.snum].alias);
   
   clbStoreMsg(MSG_COMP, MSG_ALL, msgbuf);
-  
+
+#if defined(AUTO_RECORD)
+  {                             /* automatically record all games */
+    extern void startRecord(int);
+
+    if (Context.recmode != RECMODE_ON)
+      startRecord(FALSE);
+  }
+#endif
 
   /* client updates will be handled by updateProc */
   /* While we're alive, field commands and process them. */
@@ -1680,7 +1699,7 @@ int welcome( int *unum )
   sInfo.isLoggedIn = TRUE;
 
   if ( ! clbGetUserNum( unum, name, 0 ) )
-    {				
+    {
       flags |= SPCLNTSTAT_FLAG_NEW;
       /* Must be a new player. */
       if ( ConqInfo->closed )
@@ -1690,7 +1709,6 @@ int welcome( int *unum )
 	  return ( FALSE );
 	}
       team = rndint( 0, NUMPLAYERTEAMS - 1 );
-      clog("CONQD: TEAM = %d", team);
       
       cbuf[0] = EOS;
       apptitle( team, cbuf );
