@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: conquestgl.c,v 1.11 2005/12/27 21:10:41 jon Exp $
+ * $Id: conquestgl.c 635 2006-09-01 23:42:14Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -46,6 +46,8 @@
 #include "nConsvr.h"
 #include "nMeta.h"
 
+#include "conqinit.h"
+
 void catchSignals(void);
 void handleSignal(int sig);
 void conqend(void);
@@ -54,11 +56,11 @@ void printUsage()
 {
   printf("Usage: conquestgl [-m ][-s server[:port]] [-r recfile] [ -t ]\n");
   printf("                  [-f ][-g <geometry>] [ -u ]\n");
-  printf("                  [ -M <metaserver> ]\n\n");
+  printf("                  [ -M <metaserver> ] [ -B ]\n\n");
   printf("    -f               run in fullscreen mode\n");
   printf("    -g <geometry>    specify intial window width/height.\n");
   printf("                      Format is WxH (ex: 1024x768).\n");
-  printf("                      Default is 800x600.\n");
+  printf("                      Default is 1024x768.\n");
   printf("    -m               query the metaserver\n");
   printf("    -s server[:port] connect to <server> at <port>\n");
   printf("                      default: localhost:1701\n");
@@ -73,8 +75,8 @@ void printUsage()
 
                                  
   printf("    -P <cqr file>   Play back a Conquest recording (.cqr)\n");
-  printf("    -d <dly>        specify default framedelay for CQR playback.\n");
-  printf("                    (example -d .01, for 1/100sec frame delay\n");
+  printf("    -B              Benchmark mode.  When playing back a recording,\n");
+  printf("                    the default playback speed will be as fast as possible.\n");
   printf("    -u              do not attempt to use UDP from server.\n");
 
                                  
@@ -132,6 +134,67 @@ static void parseGeometry(char *geom)
   return;
 }
 
+/* utility function to look for and load all .trc files in a given dir */
+static void _loadTRCs(char *cqdir)
+{
+  char filenm[BUFFER_SIZE];
+  DIR *dirp;
+  struct dirent *direntp;
+
+  if ((dirp = opendir(cqdir)))
+    {
+      while ((direntp = readdir(dirp)) != NULL)
+        {                       /* here, we will just check out the .trc
+                                   files */
+          int len;
+          static const int trc_len = 4; /* . t r c */
+
+          if ((!strcmp(direntp->d_name, "..") ||
+               !strcmp(direntp->d_name, ".")))
+            continue;
+
+          len = strlen(direntp->d_name);
+          if (len < trc_len)
+            continue;
+          
+          if (!strncmp(&(direntp->d_name[len - trc_len]), ".trc", trc_len)) 
+            {                   /* found one */
+              snprintf(filenm, sizeof(filenm)-1, "%s/%s", 
+                       cqdir,direntp->d_name);
+
+              cqiLoadRC(CQI_FILE_TEXTURESRC_ADD, filenm, 1, 0);
+            }
+        }
+    }
+
+  return;
+}
+
+/* first load the main texturesrc and *.trc files.  Then look for and
+   load any ~/.conquest/ *.trc files */
+void loadTextureRCFiles()
+{
+  char cqdir[BUFFER_SIZE];
+  char *homevar;
+
+  /* load the main texturesrc file first */
+  cqiLoadRC(CQI_FILE_TEXTURESRC, NULL, 1, 0);
+
+  /* now load any .trc files in there (CONQETC) */
+  _loadTRCs(CONQETC);
+
+  /* now load any in the users own ~/.conquest/ dir */
+  if ((homevar = getenv("HOME")) == NULL)
+    return;
+
+  snprintf(cqdir, sizeof(cqdir)-1, "%s/.conquest", 
+           homevar);
+
+  _loadTRCs(cqdir);
+
+  return;
+}
+
 
 /*  conquest - main program */
 int main(int argc, char *argv[]) 
@@ -158,7 +221,7 @@ int main(int argc, char *argv[])
   cInfo.isLoggedIn = FALSE;
   cInfo.remoteport = CN_DFLT_PORT;
 
-  setSystemLog(FALSE);	/* use $HOME for logfile */
+  setSystemLog(FALSE, TRUE);	/* use $HOME for logfile */
   if (!getLocalhost(cInfo.localhost, MAXHOSTNAME))
     return(1);
 
@@ -167,13 +230,16 @@ int main(int argc, char *argv[])
   dspInitData();
 
   /* check options */
-  while ((i = getopt(argc, argv, "fmM:s:r:tP:d:ug:")) != EOF)    /* get command args */
+  while ((i = getopt(argc, argv, "fmM:s:r:tP:Bug:")) != EOF)    /* get command args */
     switch (i)
       {
+      case 'B':                 /* Benchmark mode, set frameDelay to 0.0 */
+        frameDelay = 0.0;
+        break;
       case 'f':
         dConf.fullScreen = TRUE;
         break;
-      case 'g':                 /* to let '-geometry' slide by *HACK* */
+      case 'g':                 
         parseGeometry(optarg);
         break;
       case 'm':
@@ -234,10 +300,6 @@ int main(int argc, char *argv[])
         Context.recmode = RECMODE_PLAYING;
         break;
 
-      case 'd':                 /* framedelay */
-        framedelay = ctor(optarg);
-        break;
-
       case 'u':
         cInfo.tryUDP = FALSE;
         break;
@@ -288,6 +350,7 @@ int main(int argc, char *argv[])
       /* turn off annoying beeps */
       UserConf.DoAlarms = FALSE;
     }
+
   if (serveropt && wantMetaList)
     {
       printf("-m ignored, since -s was specified\n");
@@ -315,6 +378,12 @@ int main(int argc, char *argv[])
              nums);
     }
 
+  /* load the globals/planets, etc */
+  cqiLoadRC(CQI_FILE_CONQINITRC, NULL, 1, 0);
+
+  /* load the main texturesrc file and any user supplied ~/.conquest/ *.trc
+     files */
+  loadTextureRCFiles();
 
   /* a parallel universe, it is */
   map_lcommon();
