@@ -3,7 +3,7 @@
 /************************************************************************
  * conquest curses using stuff
  *
- * $Id: cumisc.c,v 1.4 2004/12/13 01:40:19 jon Exp $
+ * $Id: cumisc.c 564 2006-07-24 00:52:28Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -2149,3 +2149,16 @@ void mcuNews(void)
   
 }
 
+/* planet updating (textures, etc) */
+/* for the GL client, this is defined in GL.c, for the curses client
+   this will be a noop defined in cumisc.c */
+
+int uiUpdatePlanet(int pnum)
+{
+  return TRUE;                  /* NOOP */
+}
+/* update the direction of the torp (GL only) */
+int uiUpdateTorpDir(int snum, int tnum)
+{
+  return TRUE;
+}
