@@ -2,7 +2,7 @@
 
 /************************************************************************
  *
- * $Id: gldisplay.c,v 1.12 2005/07/11 06:09:35 jon Exp $
+ * $Id: gldisplay.c 633 2006-09-01 22:02:29Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  ***********************************************************************/
@@ -76,7 +76,7 @@ static int alertcolor(int alert)
 /*    display( snum, display_info ) */
 void display( int snum, int display_info )
 {
-  int i, j, minenemy, minsenemy;
+  int i, j, k, minenemy, minsenemy;
   int outattr = 0;
   static int OldAlert = 0;
   char ch, buf[MSGMAXLINE];
@@ -330,6 +330,8 @@ void display( int snum, int display_info )
 			  color = YellowLevelColor; /* special view */
 
 			drawShip(glx, gly, Ships[i].head, ch, i, color, scale);
+                        if (SBOMBING(i))
+                          drawBombing(i);
 		      }
 		  }
 	      }
@@ -410,7 +412,7 @@ void display( int snum, int display_info )
 	      /* Nearby torpedos. */
 	      outattr = YellowLevelColor;
 	      AlertLevel = YELLOW_ALERT;
-	      c_strcpy( "Torp alert", buf );
+	      c_strcpy( "Torp Alert", buf );
 	      minenemy = 0;			/* disable nearby enemy code */
 	      dobeep = TRUE;
 	    }
@@ -456,7 +458,7 @@ void display( int snum, int display_info )
       OldAlert = AlertLevel;
     }
   
-  if ((strcmp( buf, zzbuf ) != 0) || UserConf.AltHUD)
+  if (UserConf.AltHUD || (strcmp( buf, zzbuf ) != 0))
     {
       setXtraInfo();
       setAlertLabel(buf, outattr);
@@ -465,41 +467,25 @@ void display( int snum, int display_info )
   
   /* Build and display the status info as necessary. */
   if (snum > 0) 
-    { /* we're watching a ship */  /* dwp */
-    
+    {                           /* we're watching a ship - dwp */
     /* Shields. */
     if ( Ships[snum].shields < prevsh )
       dobeep = TRUE;
     prevsh = Ships[snum].shields;
     
-    i = round( Ships[snum].shields );
+    i = k = round( Ships[snum].shields );
     if ( ! SSHUP(snum) || SREPAIR(snum) )
       i = -1;
     if ( i != zzsshields || i == -1)
       {
-	if ( i == -1 )
-	  {
-	    if (AlertLevel == YELLOW_ALERT) 
-	      color = YellowLevelColor;
-	    else if (AlertLevel == RED_ALERT)
-	      color = RedLevelColor ;
-	    else
-	      color = GreenLevelColor;
-	    
-	    setShields(i, color);
-
-	  }
-	else
-	  {
-	    if (i >= 0 && i <= 50)
-	      ShieldAttrib = RedLevelColor;
-	    else if (i >=51 && i <=80)
-	      ShieldAttrib = YellowLevelColor;
-	    else if (i >= 81)
-	      ShieldAttrib = GreenLevelColor;
-	    
-	    setShields(i, ShieldAttrib);
-	  }
+        if (k >= 0 && k <= 50)
+          ShieldAttrib = RedLevelColor;
+        else if (k >=51 && k <=80)
+          ShieldAttrib = YellowLevelColor;
+        else if (k >= 81)
+          ShieldAttrib = GreenLevelColor;
+        
+        setShields(i, ShieldAttrib);
 	zzsshields = i;
       }
     
@@ -525,7 +511,7 @@ void display( int snum, int display_info )
 	  }
 	else
 	  {
-	    setWarp(" o ");
+	    setWarp("Orbit");
 	  }
 	
 	zzswarp = x;
@@ -673,13 +659,13 @@ void display( int snum, int display_info )
       {
 	if ( i > 0 )
 	  {
-	    sprintf( buf, "%d", i );
-	    setArmies("Armies = ", buf);
+	    sprintf( buf, "%2d ", i );
+	    setArmies(buf, "armies");
 	  }
 	else if ( i < 0 )
 	  {
 	    robstr( -i, buf );
-	    setArmies("AI: ", buf);
+	    setArmies("", buf);
 	  }
 	else
 	  setArmies("", "");
@@ -717,7 +703,7 @@ void display( int snum, int display_info )
       {
 	if ( i > 0 )
 	  {
-	    sprintf( buf, "DESTRUCT MINUS %-3d", i );
+	    sprintf( buf, "DESTRUCT MINUS %3d", i );
 	    setCloakDestruct(buf, RedLevelColor);
 	  }
 	else if ( i == -1 )
