@@ -1,7 +1,7 @@
 /* 
  * misc gl funcs
  *
- * $Id: glmisc.h,v 1.3 2004/09/04 07:38:02 jon Exp $
+ * $Id: glmisc.h 552 2006-07-17 04:47:23Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -12,12 +12,11 @@
 #define VIEWANGLE 45.0
 #define TRANZ     -100.0
 
-void _GLError(char *funcname, int line);
+int _GLError(const char *funcname, const char *filename, int line);
 
-#define GLError() _GLError(__FUNCTION__, __LINE__)
+#define GLError() _GLError(__FUNCTION__, __FILE__, __LINE__)
 
-
-void mglConqLogo(dspConfig_t *dsp);
+void mglConqLogo(dspConfig_t *dsp, bool mult);
 void mglBeep(void);  
 void mglOverlayQuad(void);
 
