@@ -1,7 +1,7 @@
 /* 
  * cockpit node
  *
- * $Id: nCP.c,v 1.24 2005/12/25 20:24:00 jon Exp $
+ * $Id: nCP.c 629 2006-08-31 02:56:45Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -37,7 +37,8 @@
 #include "glmisc.h"
 #include "glfont.h"
 #include "render.h"
-
+#include "anim.h"
+#include "GL.h"
 #include "nCP.h"
 
 /* node specific states */
@@ -124,19 +125,35 @@ extern dspData_t dData;
 static Unsgn32 pingStart = 0;
 static int pingPending = FALSE;
 
+/* common output */
 #define cp_putmsg(str, lin)  setPrompt(lin, NULL, NoColor, str, NoColor)
 
+#if 0                           /* for debugging */
+void cp_putmsg(char *str, int lin)
+{
+  setPrompt(lin, NULL, NoColor, str, NoColor); 
+  clog("PUTMSG: %s", str); 
+}
+#endif
+
 static int nCPDisplay(dspConfig_t *);
 static int nCPIdle(void);
 static int nCPInput(int ch);
+static int nCPMInput(mouseData_t *mdata);
 
 static scrNode_t nCPNode = {
-  nCPDisplay,               /* display */
-  nCPIdle,                  /* idle */
-  nCPInput,                  /* input */
-  NULL
+  nCPDisplay,                   /* display */
+  nCPIdle,                      /* idle */
+  nCPInput,                     /* input */
+  nCPMInput,                    /* minput */
+  NULL                          /* animQue */
 };
 
+static animQue_t animQue;
+
+/* team torp anim states (exported) */
+animStateRec_t ncpTorpAnims[NUMPLAYERTEAMS];
+
 /* convert a KP key into an angle */
 static int _KPAngle(int ch, real *angle)
 {
@@ -723,78 +740,14 @@ static int _gettarget(char *buf, real cdefault, real *dir, char ch)
   
 }
 
-static int _chktorp(void)
-{
-  int snum = Context.snum;
-  
-  if ( SCLOAKED(snum) )
-    {
-      cp_putmsg( "The cloaking device is using all available power.",
-	       MSG_LIN1 );
-      return FALSE;
-    }
-  if ( Ships[snum].wfuse > 0 )
-    {
-      cp_putmsg( "Weapons are currently overloaded.", MSG_LIN1 );
-      return FALSE;
-    }
-  if ( Ships[snum].fuel < TORPEDO_FUEL )
-    {
-      cp_putmsg( "Not enough fuel to launch a torpedo.", MSG_LIN1 );
-      return FALSE;
-    }
-
-  return TRUE;
-}
-
-static int _chkphase(void)
-{
-  int snum = Context.snum;
-
-  if ( SCLOAKED(snum) )
-    {
-      cp_putmsg( "The cloaking device is using all available power.",
-	       MSG_LIN1 );
-      return FALSE;
-    }
-  if ( Ships[snum].wfuse > 0 )
-    {
-      cp_putmsg( "Weapons are currently overloaded.", MSG_LIN1 );
-      return FALSE;
-    }
-  if ( Ships[snum].fuel < PHASER_FUEL )
-    {
-      cp_putmsg( "Not enough fuel to fire phasers.", MSG_LIN1 );
-      return FALSE;
-    }
-
-  return TRUE;
-}
-
 static void _dophase( real dir )
 {
-  int snum = Context.snum;
+  /* we used to do some pre-checks here, but depending on lag,
+     these checks can be racy.  Now we will send the command regardless
+     of what things look like locally, and let the server deal with it. */
   
-  if ( Ships[snum].wfuse > 0 )
-    {
-      cp_putmsg( "Weapons are currently overloaded.", MSG_LIN1 );
-      return;
-    }
-  if ( Ships[snum].fuel < PHASER_FUEL )
-    {
-      cp_putmsg( "Not enough fuel to fire phasers.", MSG_LIN2 );
-      return;
-    }
-
-  if ( Ships[snum].pfuse == 0 && clbUseFuel( snum, PHASER_FUEL, 
-                                          TRUE, FALSE ) )
-    {			/* a local approximation of course */
-      cp_putmsg( "Firing phasers...", MSG_LIN2 );
-      Ships[snum].pfuse = -1;   /* fake it out until next upd */
-      sendCommand(CPCMD_FIREPHASER, (Unsgn16)(dir * 100.0));
-    }
-  else
-    cp_putmsg( ">PHASERS DRAINED<", MSG_LIN2 );
+  cp_putmsg( "Firing phasers...", MSG_LIN2 );
+  sendCommand(CPCMD_FIREPHASER, (Unsgn16)(dir * 100.0));
 
   return;
   
@@ -802,15 +755,12 @@ static void _dophase( real dir )
 
 static void _dotorp(real dir, int num)
 {
-  int snum = Context.snum;
-
-  if ( ! clbCheckLaunch( snum, num ) )
-    cp_putmsg( ">TUBES EMPTY<", MSG_LIN2 );
-  else
-    {			/* a local approx */
-      sendFireTorps(num, dir);
-      clrPrompt(MSG_LIN1);
-    }
+  /* we used to do some pre-checks here, but depending on lag,
+     these checks can be racy.  Now we will send the command regardless
+     of what things look like locally, and let the server deal with it. */
+  
+  sendFireTorps(num, dir);
+  clrPrompt(MSG_LIN1);
 
   return;
 }
@@ -1609,27 +1559,13 @@ static void _docourse( char *buf, char ch)
 /* will decloak if cloaked */
 static int _chkcloak(void)
 {
-  int snum = Context.snum;
-  string nofuel="Not enough fuel to engage cloaking device.";
-  
   clrPrompt(MSG_LIN1);
   clrPrompt(MSG_LIN2);
   
-  if ( SCLOAKED(snum) )
+  if ( SCLOAKED(Context.snum) )
     {
       sendCommand(CPCMD_CLOAK, 0);
       cp_putmsg( "Cloaking device disengaged.", MSG_LIN1 );
-      SFCLR(snum, SHIP_F_CLOAKED); /* do it locally too */
-      return FALSE;
-    }
-  if ( Ships[snum].efuse > 0 )
-    {
-      cp_putmsg( "Engines are currently overloaded.", MSG_LIN1 );
-      return FALSE;
-    }
-  if ( Ships[snum].fuel < CLOAK_ON_FUEL )
-    {
-      cp_putmsg( nofuel, MSG_LIN1 );
       return FALSE;
     }
 
@@ -1638,23 +1574,10 @@ static int _chkcloak(void)
 
 static void _docloak( char *buf, char ch)
 {
-  int snum = Context.snum;
-  string nofuel="Not enough fuel to engage cloaking device.";
-  
   clrPrompt(MSG_LIN1);
 
   if (ch == TERM_EXTRA)
-    {
-      if ( ! clbUseFuel( snum, CLOAK_ON_FUEL, FALSE, TRUE ) )
-	{			/* an approximation of course... */
-	  cp_putmsg( nofuel, MSG_LIN2 );
-	  return;
-	}
-
-      sendCommand(CPCMD_CLOAK, 0);
-      SFSET(snum, SHIP_F_CLOAKED); /* do it locally */
-      cp_putmsg( "Cloaking device engaged.", MSG_LIN2 );
-    }
+    sendCommand(CPCMD_CLOAK, 0);
 
   clrPrompt(MSG_LIN1);
 
@@ -2121,20 +2044,19 @@ static void command( int ch )
       prompting = TRUE;
       break;
     case 'f':				/* phasers */
-      if (_chkphase())
-        {
-          state = S_TARGET;
-          desttarg = T_PHASER;
-          prm.preinit = False;
-          prm.buf = cbuf;
-          prm.buflen = MSGMAXLINE;
-          prm.pbuf = "Fire phasers: ";
-          prm.terms = TERMS;
-          prm.index = MSG_LIN1;
-          prm.buf[0] = EOS;
-          setPrompt(prm.index, prm.pbuf, NoColor, prm.buf, NoColor);
-          prompting = TRUE;
-        }
+      {
+        state = S_TARGET;
+        desttarg = T_PHASER;
+        prm.preinit = False;
+        prm.buf = cbuf;
+        prm.buflen = MSGMAXLINE;
+        prm.pbuf = "Fire phasers: ";
+        prm.terms = TERMS;
+        prm.index = MSG_LIN1;
+        prm.buf[0] = EOS;
+        setPrompt(prm.index, prm.pbuf, NoColor, prm.buf, NoColor);
+        prompting = TRUE;
+      }
       break;
     case 'F':				/* phasers, same direction */
       _dophase(lastphase);
@@ -2232,36 +2154,34 @@ static void command( int ch )
       _doorbit( Context.snum );
       break;
     case 'P':				/* photon torpedo burst */
-      if (_chktorp())
-        {
-          state = S_TARGET;
-          desttarg = T_BURST;
-          prm.preinit = False;
-          prm.buf = cbuf;
-          prm.buflen = MSGMAXLINE;
-          prm.pbuf = "Torpedo burst: ";
-          prm.terms = TERMS;
-          prm.index = MSG_LIN1;
-          prm.buf[0] = EOS;
-          setPrompt(prm.index, prm.pbuf, NoColor, prm.buf, NoColor);
-          prompting = TRUE;
-        }
+      {
+        state = S_TARGET;
+        desttarg = T_BURST;
+        prm.preinit = False;
+        prm.buf = cbuf;
+        prm.buflen = MSGMAXLINE;
+        prm.pbuf = "Torpedo burst: ";
+        prm.terms = TERMS;
+        prm.index = MSG_LIN1;
+        prm.buf[0] = EOS;
+        setPrompt(prm.index, prm.pbuf, NoColor, prm.buf, NoColor);
+        prompting = TRUE;
+      }
       break;
     case 'p':				/* photon torpedoes */
-      if (_chktorp())
-        {
-          state = S_TARGET;
-          desttarg = T_TORP;
-          prm.preinit = False;
-          prm.buf = cbuf;
-          prm.buflen = MSGMAXLINE;
-          prm.pbuf = "Launch torpedo: ";
-          prm.terms = TERMS;
-          prm.index = MSG_LIN1;
-          prm.buf[0] = EOS;
-          setPrompt(prm.index, prm.pbuf, NoColor, prm.buf, NoColor);
-          prompting = TRUE;
-        }
+      {
+        state = S_TARGET;
+        desttarg = T_TORP;
+        prm.preinit = False;
+        prm.buf = cbuf;
+        prm.buflen = MSGMAXLINE;
+        prm.pbuf = "Launch torpedo: ";
+        prm.terms = TERMS;
+        prm.index = MSG_LIN1;
+        prm.buf[0] = EOS;
+        setPrompt(prm.index, prm.pbuf, NoColor, prm.buf, NoColor);
+        prompting = TRUE;
+      }
       break;
     case 'Q':				/* self destruct */
       if ( SCLOAKED(Context.snum) )
@@ -2307,18 +2227,8 @@ static void command( int ch )
         mglBeep();
       break;
     case 'R':				/* repair mode */
-      if ( ! SCLOAKED(Context.snum) )
-	{
-          clrPrompt(MSG_LIN1);
-	  sendCommand(CPCMD_REPAIR, 0);
-	}
-      else
-	{
-          clrPrompt(MSG_LIN2);
-	  cp_putmsg(
-		   "You cannot repair while the cloaking device is engaged.",
-		   MSG_LIN1 );
-	}
+      clrPrompt(MSG_LIN1);
+      sendCommand(CPCMD_REPAIR, 0);
       break;
     case 't':
       if (_chktow())
@@ -2428,12 +2338,57 @@ void nCPInit(void)
   clientFlags = 0;
 
   /* init timers */
-  rftime = glutGet(GLUT_ELAPSED_TIME);
+  rftime = frameTime;
   lastblast = Ships[Context.snum].lastblast;
   lastphase = Ships[Context.snum].lastphase;
   pingPending = FALSE;
   pingStart = 0;
 
+  if (!nCPNode.animQue)
+    {
+      int i;
+
+      nCPNode.animQue = &animQue;
+      animQueInit(nCPNode.animQue);
+
+      /* now setup the blinkers */
+      /* these are toggle animations that never expire, so they
+         only need to be done once at inittime (but for each node
+         that wishes to make use of them. */
+      if (!animInitState("onesec", &GLBlinkerOneSec, NULL))
+        clog("%s: failed to init animstate for animation 'onesec'",
+             __FUNCTION__);
+      else
+        animQueAdd(nCPNode.animQue, &GLBlinkerOneSec);
+
+      if (!animInitState("halfsec", &GLBlinkerHalfSec, NULL))
+        clog("%s: failed to init animstate for animation 'halfsec'",
+             __FUNCTION__);
+      else
+        animQueAdd(nCPNode.animQue, &GLBlinkerHalfSec);
+
+      if (!animInitState("qtrsec", &GLBlinkerQtrSec, NULL))
+        clog("%s: failed to init animstate for animation 'qtrsec'",
+             __FUNCTION__);
+      else
+        animQueAdd(nCPNode.animQue, &GLBlinkerQtrSec);
+
+      /* now setup the team torp animators */
+      for (i=0; i<NUMPLAYERTEAMS; i++)
+        {
+          char nm[TEXFILEMAX];
+
+          snprintf(nm, TEXFILEMAX - 1, "ship%c-torp", 
+                   Teams[i].name[0]);
+
+          if (!animInitState(nm, &ncpTorpAnims[i], NULL))
+            clog("%s: failed to init animstate for animation '%s'",
+                 __FUNCTION__, nm);
+          else
+            animQueAdd(nCPNode.animQue, &ncpTorpAnims[i]);
+        }
+    }
+
   setNode(&nCPNode);
 
   return;
@@ -2442,8 +2397,16 @@ void nCPInit(void)
 
 static int nCPDisplay(dspConfig_t *dsp)
 {
+  /* Older servers do not send the ships SHIP_F_BOMBING flag, so if
+     our state is S_BOMBING, but our ship isn't marked as such (by the
+     server), we fake it by setting dobombing, so you can at least see
+     your own ship bombing a planet.  If the server is new enough to
+     send this flag, gldisplay() will display it instead of this
+     boolean. */
+  int dobombing = ((state == S_BOMBING) && !SBOMBING(Context.snum));
+
   /* Viewer */
-  renderViewer(UserConf.doVBG);
+  renderViewer(UserConf.doVBG, dobombing);
 
   /* Main/Hud */
   renderHud(dostats);
@@ -2459,7 +2422,6 @@ static int nCPIdle(void)
   spAck_t *sack;
   int pkttype;
   int now;
-  int gnow = glutGet(GLUT_ELAPSED_TIME);
   Unsgn8 buf[PKT_MAXSIZE];
   int difftime = dgrand( Context.msgrand, &now );
   int sockl[2] = {cInfo.sock, cInfo.usock};
@@ -2509,9 +2471,6 @@ static int nCPIdle(void)
       return NODE_EXIT;
     }
 
-  /* send a UDP keepalive packet if it's time */
-  sendUDPKeepAlive();
-
   /* send a ping if it's time */
   if (!pingPending && ((iternow - pingtime) > pingwait))
     {                           /* send a ping request */
@@ -2535,7 +2494,8 @@ static int nCPIdle(void)
       clbPlanetDrive(tdelta / 1000.0);
       clbTorpDrive(tdelta / 1000.0);
       iterstart = iternow;
-      recordGenTorpLoc();
+      if (Context.recmode == RECMODE_ON)
+        recordGenTorpLoc();
     }
 
   if (clientFlags & SPCLNTSTAT_FLAG_KILLED)
@@ -2606,10 +2566,13 @@ static int nCPIdle(void)
           }
     }
 
-  if ((gnow - rftime) > (int)((1.0 / (real)Context.updsec) * 1000.0))
-    {                           /* record a frame */
-      recordUpdateFrame();
-      rftime = gnow;
+  if (Context.recmode == RECMODE_ON)
+    {
+      if ((iternow - rftime) > (int)((1.0 / (real)Context.updsec) * 1000.0))
+        {                           /* record a frame */
+          recordUpdateFrame();
+          rftime = iternow;
+        }
     }
 
   return NODE_OK;
@@ -2639,6 +2602,13 @@ static int nCPInput(int ch)
       return NODE_OK;
     }
 
+  if ((CQ_CHAR(ch) == 'G' || CQ_CHAR(ch) == 'g') && 
+      CQ_MODIFIER(ch) & CQ_KEY_MOD_ALT)
+    {
+      UserConf.DoTacBkg = !UserConf.DoTacBkg;
+      return NODE_OK;
+    }
+
   ch = CQ_CHAR(ch) | CQ_FKEY(ch);
 
   if (ch == 0x1c)
@@ -3180,3 +3150,32 @@ static int nCPInput(int ch)
   return NODE_OK;
 }
 
+static int nCPMInput(mouseData_t *mdata)
+{
+#if 0
+  clog ("%s: mod = %08x, button = %d state = %d\n", 
+        __FUNCTION__,
+        mdata->mod,
+        mdata->button,
+        mdata->state);
+#endif
+
+  /* check to see if event is in viewer area, and a button press */
+  if (((mdata->x >= dConf.vX) && (mdata->x <= (dConf.vX + dConf.vW)) &&
+       (mdata->y >= dConf.vY) && (mdata->y <= (dConf.vY + dConf.vH))) &&
+      (mdata->state == CQ_MOUSE_BDOWN))
+
+    {
+      /* compute an angle relative to center of viewer and do
+         the macro thang */
+      real dir = angle((real)(dConf.vX + (dConf.vW / 2.0)), 
+                       (real)(dConf.vY + (dConf.vH / 2.0)), 
+                       (real)mdata->x, 
+                       (real)(dConf.vY + dConf.vH) - ((real)mdata->y - dConf.vY)
+                       );
+
+      DoMouseMacro(mdata->button, mdata->mod, dir);
+    }
+
+  return NODE_OK;
+}
