@@ -1,7 +1,7 @@
 /* 
  * play node.  Sets up for the cockpit (CP).
  *
- * $Id: nPlay.c,v 1.10 2005/12/28 06:13:28 jon Exp $
+ * $Id: nPlay.c 552 2006-07-17 04:47:23Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -46,7 +46,8 @@ static scrNode_t nPlayNode = {
   nPlayDisplay,               /* display */
   nPlayIdle,                  /* idle */
   nPlayInput,                  /* input */
-  NULL                          /* next */
+  NULL,                         /* minput */
+  NULL                          /* animQue */
 };
 
 /* select a system to enter */
@@ -244,15 +245,15 @@ static int nPlayIdle(void)
       /* start recording if neccessary */
       if (Context.recmode == RECMODE_STARTING)
         {
-          if (recordInitOutput(Context.unum, getnow(NULL, 0), Context.snum))
+          if (recordInitOutput(Context.unum, getnow(NULL, 0), Context.snum,
+                               FALSE))
             {
               Context.recmode = RECMODE_ON;
             }
           else
             Context.recmode = RECMODE_OFF;
         }
-
-
+      
       /* need to tell the server to resend all the crap it already
          sent in menu - our ship may have chenged */
       sendCommand(CPCMD_RELOAD, 0);
