@@ -1,7 +1,7 @@
 /* 
  * nCP help node
  *
- * $Id: nPlayBHelp.c,v 1.6 2004/09/04 07:38:02 jon Exp $
+ * $Id: nPlayBHelp.c 552 2006-07-17 04:47:23Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -31,7 +31,9 @@ static scrNode_t nPlayBHelpNode = {
   nPlayBHelpDisplay,            /* display */
   NULL,                         /* idle */
   nPlayBHelpInput,               /* input */
-  NULL                          /* next */
+  NULL,                         /* minput */
+  NULL                          /* animQue */
+
 };
 
 
