@@ -1,7 +1,7 @@
 /* 
  * server command handling
  *
- * $Id: servercmd.h,v 1.2 2003/11/02 20:53:00 jon Exp $
+ * $Id: servercmd.h 552 2006-07-17 04:47:23Z jon $
  *
  * Copyright 2003 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -17,7 +17,5 @@
 #include "record.h"
 
 int checkOperExec(int from, int to, char *msg);
-void startRecord(void);
-void stopRecord(void);
 
 #endif /* _SERVERCMD_H */
