@@ -1,7 +1,7 @@
 /* 
  * Ship structure
  *
- * $Id: ship.h,v 1.6 2003/11/02 20:53:00 jon Exp $
+ * $Id: ship.h 552 2006-07-17 04:47:23Z jon $
  *
  * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
  */
@@ -22,6 +22,7 @@
 #define SHIP_F_ROBOT       0x0020 /* true if is a robot ship */
 #define SHIP_F_MAP         0x0040 /* strategic map or not */
 #define SHIP_F_SCANDIST    0x0080 /* ship dist < ACCINFO_DIST */
+#define SHIP_F_BOMBING     0x0100 /* ship is currently bombing */
 
 /* helpers */
 #define SCLOAKED(x)  ( bitIsSet(Ships[x].flags, SHIP_F_CLOAKED) )
@@ -32,6 +33,7 @@
 #define SROBOT(x)    ( bitIsSet(Ships[x].flags, SHIP_F_ROBOT) )
 #define SMAP(x)      ( bitIsSet(Ships[x].flags, SHIP_F_MAP) )
 #define SSCANDIST(x) ( bitIsSet(Ships[x].flags, SHIP_F_SCANDIST) )
+#define SBOMBING(x)  ( bitIsSet(Ships[x].flags, SHIP_F_BOMBING) )
 
 #define SFSET(x, b)  (bitSet(Ships[x].flags, b))
 #define SFCLR(x, b)  (bitClear(Ships[x].flags, b))
